pub struct Error { /* private fields */ }Expand description
Indicates that an error occurred when reloading a layer.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn is_poisoned(&self) -> bool
pub fn is_poisoned(&self) -> bool
Returns true if this error occurred because the layer was poisoned by
a panic on another thread.
Sourcepub fn is_dropped(&self) -> bool
pub fn is_dropped(&self) -> bool
Returns true if this error occurred because the Subscriber
containing the reloadable layer was dropped.